from lib2to3.fixes.fix_input import context

from django.shortcuts import render,redirect
from django.http import HttpResponse
import requests
import json

from consumerapp.forms import EmployeeForm

def EmployeeListView(request):
    response = requests.get("http://127.0.0.1:3399/api/employees/") # RESTAPI URL--->> JSON format

    # response = requests.get("http://127.0.0.1:3399/app/employee/list/") # Django UJRL--->> HTML Format

    if response.status_code == 200:
        try:
            employee_list = json.loads(response.text)
        except:
            context = {
                "message" : "Sorry, Accessed data not available in JSON format"
            }
            return render(request, 'consumerapp/employee_list.html', context)
        else:
            context = {
                "employee_list": employee_list
            }
            return render(request, 'consumerapp/employee_list.html', context)
    elif response.status_code == 404:
        context = {
            "message" : "Requested Employees Does Not Exist"
        }
        return render(request, 'consumerapp/employee_list.html', context)
    else:
        context = {
            "message" : "Something Went Wrong"
        }
        return render(request, 'consumerapp/employee_list.html', context)


def EmployeeDetailView(request, pk):
    response = requests.get("http://127.0.0.1:3399/api/employees/"+str(pk)+"/")
    if response.status_code == 200:
        try:
            employee = json.loads(response.text)
        except:
            context = {
                "message" : "Sorry, Accessed data not available in JSON format"
            }
            return render(request, 'consumerapp/employee_detail.html', context)
        else:
            context = {
                "employee": employee
            }
            return render(request, 'consumerapp/employee_detail.html', context)
    elif response.status_code == 404:
        context = {
            "message" : "Requested Employee Does Not Exist"
        }
        return render(request, 'consumerapp/employee_detail.html', context)
    else:
        context = {
            "message" : "Something Went Wrong"
        }
        return render(request, 'consumerapp/employee_detail.html', context)


def EmployeeDeleteView(request, pk):
    if request.method == "POST":
        response = requests.delete("http://127.0.0.1:3399/api/employees/" + str(pk) + "/")
        if response.status_code == 204:
            return redirect("employee_list")
            # context = {
            #     "message" : "Employee Deleted Successfully"
            # }
            # return render(request, 'consumerapp/employee_delete.html', context)
        else:
            context = {
                "message" : "Something Went Wrong"
            }
            return render(request, 'consumerapp/employee_delete.html', context)

    else:
        response = requests.get("http://127.0.0.1:3399/api/employees/"+str(pk)+"/")
        if response.status_code == 200:
            try:
                employee = json.loads(response.text)
            except:
                context = {
                    "message" : "Sorry, Accessed data not available in JSON format"
                }
                return render(request, 'consumerapp/employee_delete.html', context)
            else:
                context = {
                    "employee": employee
                }
                return render(request, 'consumerapp/employee_delete.html', context)
        elif response.status_code == 404:
            context = {
                "message" : "Requested Employee Does Not Exist"
            }
            return render(request, 'consumerapp/employee_delete.html', context)
        else:
            context = {
                "message" : "Something Went Wrong"
            }
            return render(request, 'consumerapp/employee_delete.html', context)



def EmployeeCreateView(request):
    if request.method == "POST":
        form = EmployeeForm(request.POST)
        if form.is_valid():
            employee_data = {
                "ename" : request.POST.get("ename"),
                "salary" : request.POST.get("salary"),
                "city" : request.POST.get("city"),
                "email" : request.POST.get("email"),
            }
            response = requests.post("http://127.0.0.1:3399/api/employees/", data=employee_data)
            if response.status_code == 201:
                return redirect("employee_list")
                # context = {
                #     "message" : "Requested Employee Created"
                # }
                # return render(request, 'consumerapp/employee_create.html', context)
            elif response.status_code == 400:
                context = {
                    "message" : "Requested Employee Does Not Created"
                }
                return render(request, 'consumerapp/employee_create.html', context)
            else:
                context = {
                    "message" : "Something Went Wrong"
                }
                return render(request, 'consumerapp/employee_create.html', context)


    else:
        form = EmployeeForm()
        context = {
            "form": form
        }
        return render(request, 'consumerapp/employee_create.html', context)



def EmployeeUpdateView(request, pk):
    if request.method == "POST":
        form = EmployeeForm(request.POST)
        if form.is_valid():
            employee_data = {
                "ename": request.POST.get("ename"),
                "salary": request.POST.get("salary"),
                "city": request.POST.get("city"),
                "email": request.POST.get("email"),
            }
            response = requests.put("http://127.0.0.1:3399/api/employees/"+str(pk)+"/", data=employee_data)
            if response.status_code == 200:
                return redirect("employee_list")
            elif response.status_code == 400:
                context = {
                    "message" : "Requested Employee Does Not Updated"
                }
                return render(request, 'consumerapp/employee_update.html', context)
            else:
                context = {
                    "message" : "Something Went Wrong"
                }
                return render(request, 'consumerapp/employee_update.html', context)
        else:
            context = {
                "message" : "Form object is not valid"
            }
            return render(request, 'consumerapp/employee_update.html', context)

    else:
        response = requests.get("http://127.0.0.1:3399/api/employees/" + str(pk) + "/")
        if response.status_code == 200:
            try:
                employee = json.loads(response.text)
            except:
                context = {
                    "message" : "Sorry, Accessed data not available in JSON format"
                }
                return render(request, 'consumerapp/employee_update.html', context)
            else:
                form = EmployeeForm(employee)
                context = {
                    "form": form
                }
                return render(request, 'consumerapp/employee_update.html', context)
        elif response.status_code == 404:
            context = {
                "message" : "Requested Employee Does Not Exist"
            }
            return render(request, 'consumerapp/employee_update.html', context)
        else:
            context = {
                "message" : "Something Went Wrong"
            }
            return render(request, 'consumerapp/employee_update.html', context)



